@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-""" icdiff.py
+"""icdiff.py
 
 Author: Jeff Kaufman, derived from difflib.HtmlDiff
 
@@ -11,7 +11,7 @@ Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation;
 All Rights Reserved
 
 Based on Python's difflib.HtmlDiff,
-with changes to provide console output instead of html output.  """
+with changes to provide console output instead of html output."""
 
 import os
 import stat
@@ -22,10 +22,9 @@ from optparse import Option, OptionParser
 import re
 import filecmp
 import unicodedata
-import codecs
 import fnmatch
 
-__version__ = "2.0.7"
+__version__ = "2.0.9"
 
 # Exit code constants
 EXIT_CODE_SUCCESS = 0
@@ -735,41 +734,9 @@ def create_option_parser():
 
 
 def set_cols_option(options):
-    if os.name == "nt":
-        try:
-            import struct
-            from ctypes import windll, create_string_buffer
+    import shutil
 
-            fh = windll.kernel32.GetStdHandle(-12)  # stderr is -12
-            csbi = create_string_buffer(22)
-            windll.kernel32.GetConsoleScreenBufferInfo(fh, csbi)
-            res = struct.unpack("hhhhHhhhhhh", csbi.raw)
-            options.cols = res[7] - res[5] + 1  # right - left + 1
-            return
-
-        except Exception:
-            pass
-
-    else:
-
-        def ioctl_GWINSZ(fd):
-            try:
-                import fcntl
-                import termios
-                import struct
-
-                cr = struct.unpack(
-                    "hh", fcntl.ioctl(fd, termios.TIOCGWINSZ, "1234")
-                )
-            except Exception:
-                return None
-            return cr
-
-        cr = ioctl_GWINSZ(0) or ioctl_GWINSZ(1) or ioctl_GWINSZ(2)
-        if cr and cr[1] > 0:
-            options.cols = cr[1]
-            return
-    options.cols = 80
+    options.cols = shutil.get_terminal_size().columns
 
 
 def validate_has_two_arguments(parser, args):
@@ -877,7 +844,7 @@ def diff(options, a, b):
 
 def read_file(fname, options):
     try:
-        with codecs.open(fname, encoding=options.encoding, mode="rb") as inf:
+        with open(fname, encoding=options.encoding, newline="") as inf:
             return inf.readlines()
     except UnicodeDecodeError as e:
         codec_print(
